@@ -1,7 +1,7 @@
 #Helper function to compute ratio Estimator total for bootstrapping
 
 ratioEstimatort <- function(data, tau_x, indices){
-  #data: 1st column:y, 2nd column:pis, rest: x_sample_d
+  #data: 1st column:y, 2nd column:pis, rest: xsample_d
   d <- data[indices,]
   
   #y
@@ -10,12 +10,12 @@ ratioEstimatort <- function(data, tau_x, indices){
   #pis 
   pis <- d[,2]
   
-  #x_sample
-  x_sample <- d[, 3]
+  #xsample
+  xsample <- d[, 3]
   
   #Estimator
   tyHT <- horvitzThompson(y=y,pi=pis)$pop_total
-  txHT <- horvitzThompson(y=x_sample,pi=pis)$pop_total
+  txHT <- horvitzThompson(y=xsample,pi=pis)$pop_total
   
   return(as.vector(tau_x/txHT*tyHT))
 }
